#ifndef PLAYER_CONTROLLER_H
#define PLAYER_CONTROLLER_H

#include "core/scene.h"
#include "core/scene_node_entity.h"
#include "core/transformable.h"
#include "core/renderable.h"
#include "utils/drop.h"
#include "utils/mirror.h"

// Test object created to generally test game features
typedef struct PlayerController {
    SceneNode *node;
    Transformable transform;
    Vector2 fly_input;
    Vector2 rotation;
    float speed;
    bool stopped;
} PlayerController;

SceneNode *CreatePlayerController();
void DestroyPlayerController(PlayerController *self);

extern void PlayerControllerEnterTree(PlayerController *self);
extern void PlayerControllerExitTree(PlayerController *self);
extern void PlayerControllerTick(PlayerController *self, double delta);

extern void PlayerControllerLeftInput(PlayerController *self, bool value);
extern void PlayerControllerRightInput(PlayerController *self, bool value);
extern void PlayerControllerUpInput(PlayerController *self, bool value);
extern void PlayerControllerDownInput(PlayerController *self, bool value);
extern void PlayerControllerStopInput(PlayerController *self, bool value);

DECL_REFLECT(PlayerController);
decl_typeclass_impl(SceneNodeEntity, PlayerController);
decl_typeclass_impl(Drop, PlayerController);

#endif // !PLAYER_CONTROLLER_H
